==> spongeapi-8.0.0-20210211.013413-350-sources.jar: org/spongepowered/api/world/biome/BiomeSamplers.java <==
/*
 * This file is part of SpongeAPI, licensed under the MIT License (MIT).
 *
 * Copyright (c) SpongePowered <https://www.spongepowered.org>
 * Copyright (c) contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.spongepowered.api.world.biome;

import org.spongepowered.api.Sponge;

public final class BiomeSamplers {

    // @formatter:off

    // SORTFIELDS:ON

    public static final BiomeSampler COLUMN_FUZZED = Sponge.getGame().getFactoryProvider().provide(BiomeSampler.Factory.class).columnFuzzed();

    public static final BiomeSampler FUZZY = Sponge.getGame().getFactoryProvider().provide(BiomeSampler.Factory.class).fuzzy();

    public static final BiomeSampler DEFAULT = Sponge.getGame().getFactoryProvider().provide(BiomeSampler.Factory.class).defaultFinder();

    // SORTFIELDS:OFF

    // @formatter:on

    private BiomeSamplers() {
    }

}

==> spongeapi-8.0.0-20220108.065912-540-sources.jar: org/spongepowered/api/world/biome/BiomeSamplers.java <==
/*
 * This file is part of SpongeAPI, licensed under the MIT License (MIT).
 *
 * Copyright (c) SpongePowered <https://www.spongepowered.org>
 * Copyright (c) contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.spongepowered.api.world.biome;

import org.spongepowered.api.Sponge;

public final class BiomeSamplers {

    // @formatter:off

    // SORTFIELDS:ON

    public static final BiomeSampler COLUMN_FUZZED = Sponge.game().factoryProvider().provide(BiomeSampler.Factory.class).columnFuzzed();

    public static final BiomeSampler FUZZY = Sponge.game().factoryProvider().provide(BiomeSampler.Factory.class).fuzzy();

    public static final BiomeSampler DEFAULT = Sponge.game().factoryProvider().provide(BiomeSampler.Factory.class).defaultFinder();

    // SORTFIELDS:OFF

    // @formatter:on

    private BiomeSamplers() {
    }

}
